@@ -29,10 +29,10 @@ class YouGetTests(unittest.TestCase):
             'http://www.youtube.com/watch?v=pzKerr0JIPA', info_only=True
         )
         youtube.download('http://youtu.be/pzKerr0JIPA', info_only=True)
-        youtube.download(
-            'http://www.youtube.com/attribution_link?u=/watch?v%3DldAKIzq7bvs%26feature%3Dshare',  # noqa
-            info_only=True
-        )
+        #youtube.download(
+        #    'http://www.youtube.com/attribution_link?u=/watch?v%3DldAKIzq7bvs%26feature%3Dshare',  # noqa
+        #    info_only=True
+        #)
         #youtube.download(
         #    'https://www.youtube.com/watch?v=Fpr4fQSh1cc', info_only=True
         #)
@@ -40,6 +40,9 @@ class YouGetTests(unittest.TestCase):
     def test_acfun(self):
         acfun.download('https://www.acfun.cn/v/ac11701912', info_only=True)
 
+    #def test_bilibili(self):
+    #    bilibili.download('https://www.bilibili.com/video/BV1sL4y177sC', info_only=True)
+
     #def test_soundcloud(self):
         ## single song
         #soundcloud.download(
@@ -50,10 +53,9 @@ class YouGetTests(unittest.TestCase):
         #    'https://soundcloud.com/anthony-flieger/sets/cytus', info_only=True
         #)
 
-    #def tests_tiktok(self):
-    #    tiktok.download('https://www.tiktok.com/@nmb48_official/video/6850796940293164290', info_only=True)
-    #    tiktok.download('https://t.tiktok.com/i18n/share/video/6850796940293164290/', info_only=True)
-    #    tiktok.download('https://vt.tiktok.com/UGJR4R/', info_only=True)
+    def test_tiktok(self):
+        tiktok.download('https://www.tiktok.com/@nmb48_official/video/6850796940293164290', info_only=True)
+        tiktok.download('https://t.tiktok.com/i18n/share/video/6850796940293164290/', info_only=True)
 
 
 if __name__ == '__main__':
